#!/bin/bash
#
# VLE (g)vlam main script 
#

###
# (Default) settings 
# 



########################################################################
# Functions (BASH ONLY!) 
########################################################################

Abort()
{
  # abort startup 
  Println "***Fatal:" $@
  exit 1
}

Println()
{
  echo "wsvlam:" "$@" 
}

Debug()
{
  if [ -n $VERBOSE ]  ; then
     Println "-" "$@"
  fi
}

checkjava()
{

# To specify the required version, set the REQUIRED_VERSION to the major 
# version required, e.g. 1.3, but not 1.3.1.

REQUIRED_VERSION=1.6
source $VLAM_COMPOSER/bin/detect-java.sh $REQUIRED_VERSION
echo "JAVA_HOME=" $JAVA_HOME
export PATH=$JAVA_HOME/bin:$PATH
}

setclasspath(){
 for i in $VLAM_COMPOSER/lib/*.jar
  do CLASSPATH=$i:$CLASSPATH
  done

 #for i in $GLOBUS_LOCATION/lib/*.jar
 #do CLASSPATH=$i:$CLASSPATH
 #done
 export CLASSPATH
 #echo $CLASSPATH

}

commandline()
{

    checkjava 
    setclasspath
   $JAVA_HOME/bin/java nl.wtcw.vle.gui.Bootstrap nl.wtcw.vle.gui.monitor.SetupAndLaunchTopology $*
    exit 
}

cmd(){
setclasspath

echo start following commandline $*
echo VLAM_COMPOSER =$VLAM_COMPOSER

$JAVA_HOME/bin/java nl.wtcw.vle.gui.Bootstrap nl.wtcw.vle.gui.monitor.SetupAndLaunchTopology $VLAM_COMPOSER/etc/wsvlam_submit.xml -paramvalue wsvlamshell.1140610589.commandline $*
exit
}

startmonitoring(){
   setclasspath
  
   echo start monitoring $*
   #echo CLASSPATH= $CLASSPATH
   #echo commandline executed: $JAVA_HOME/bin/java  nl.wtcw.vle.gui.monitor.CLMonitor $* 

   $JAVA_HOME/bin/java  nl.wtcw.vle.gui.Bootstrap nl.wtcw.vle.gui.monitor.CLMonitor $*
   exit
}
initconfig()
{
   if [ -z "$GLOBUS_LOCATION" ] ; then
    GLOBUS_LOCATION="put_here_GLOBUS_LOCATION"
    Println "WARNING: GLOBUS_LOCATION is not defined, set this variable manually"
   fi

  if [ -z "$VLET_INSTALL" ] ; then
   VLET_HOME="put_here_VLET_HOME"
   Println "=================================================================="
   Println "WARNING: VLET_HOME is not defined, set this variable manually"
   Println "DAS3 users: "
   Println "   load VLET as a module use the following commands:"
   Println "     $ module avail  (to see available modules)"  
   Println "     $ module load  <module-name> (example module load vlet/0.8.0)"
   Println "     $ wsvlam-composer-start.sh -initconf (to complete the configuration"
   Println""
   Println "Other systems: "
   Println "   define the environment variable VLET_INSTALL, it should point to"
   Println "   location where VLET is installed"
   Println "==================================================================="    
   exit 1
   fi

  if [ ! -z "$VLAM_INSTALL" ] ; then
   
  CONF_TMP=$HOME/.vlecomposer

  Println "Creating new configuration"
     sed -e "s@put_here_VLAM_INSTALL*@$VLAM_INSTALL@"\
	 -e "s@put_here_VLET_HOME*@$VLET_INSTALL@"\
         -e "s@put_here_GLOBUS_LOCATION*@$GLOBUS_LOCATION@"\
        $VLAM_INSTALL/composer/etc/vlecomposer > $CONF_TMP
  else
      Println "=================================================================="
      Println "WARNING: VLAM_INSTALL is not defined, set this variable manually"
      Println "DAS3 users: "
      Println "   load VLAM as a module use the following commands:"
      Println "     $ module avail  (to see available modules)"
      Println "     $ module load  <module-name> (example module load wsvlam/cur)"
      Println "     $ wsvlam-composer-start.sh -initconf (to complete the configuration"
      Println""
      Println "Other systems: "
      Println "   define the environment variable VLAM_INSTALL, it should point to"
      Println "   location where WS-VLAM is installed"
      Println "===================================================================" 
      exit 1
  fi

   Println "==============================================================="
   Println "WARNING: the URLS to WS-VLAM services are set to the default" 
   Println "   values, on DAS3 (ws-vlam services are running on pc-vlab19" 
   Println ""                                                               
   Println "   To change the default configuration start the WS-VLAM composer:"
   Println "	 $ wsvlam-composer-start.sh" 
   Println "   and use the File menu > options " 
   Println "==============================================================="
}

startwsvlam()
{
   setclasspath 
#   $JAVA_HOME/bin/java -jar $VLAM_COMPOSER/lib/vleboot.jar 
   $JAVA_HOME/bin/java nl.wtcw.vle.gui.Bootstrap   
 
}   

#######################################################################
#
######################################################################

DIR=`dirname "$0"`
# get absolut path 
DIR=`cd $DIR; pwd`

if [ `basename $DIR` = "bin" ] ; then
#   Debug "Stripping bin of path: $DIR"
   DIR=`dirname $DIR`
fi

# Always use the vlam install from where the script is installed 

VLAM_COMPOSER="$DIR"


# simple sanity check 

if [ -f $VLAM_COMPOSER/bin ] ;then
        # script is not placed right. Wrong or broken installation 
        Abort "$VLAM_COMPOSER/bin not found"
fi


########################################################################
# Handle arguments 
########################################################################

USAGE="wsvlam-composer-start.sh: [-help] [-version] [-initconf] [-monitor workflow_EPR.xml] [-nogui workflow.xml [-paramvalue moduleName.moduleID.parameterName paramValue] -save filename]"

# parse all arguments 

while [ -n "$1" ] ; do   
   ARG1="$1"
   ARG2="$2"
   case "$ARG1" in
     
     -version)
        VLAM_VERSION=`cat $VLAM_COMPOSER/etc/VLAM_VERSION`;
        echo " wsvlam version : $VLAM_VERSION"
        echo " VL-e project 2004-2009"
        exit 1
        ;;
     -initconf)
	initconfig
         exit 1
        ;;
     -help)
	 Println $USAGE
	 exit 1
	;;	
     -nogui)
        shift 
	commandline $*
	;; 
     -monitor)
        shift
        startmonitoring $*
        ;;
     -cmd)
        shift
        cmd $*
        ;;
     *)
       shift
       ;;
    esac

done

### Post arguments 

########################################################################
# check runtime environment (bootstrap, before any configuration)
########################################################################

# Bootstrap environment: check where this script is located 
# This script should reside in VLAM_INSTALL (linked) or VLAM_INSTALL/bin (real path) 

DIR=`dirname "$0"`
# get absolut path 
DIR=`cd $DIR; pwd`

checkjava
startwsvlam

