#!/bin/bash 
##
# Project : VLET
# File    : vletenv.sh
# Info:
#           This script sets the VLeT environment. 
#           Most functionality has moved to the bootstrap class
#           which finds the libraries and sets the classpath. 
#           See: nl.wtcw.vls.bootstrap.* package 
#           Note: this file is sourced, do not use 'exit' 
#
 
###
# Default Settings: 
# 
cygwin=false;
linux=false; 

###
#
# functions

println()
{
    # copy to stderr ! 
	echo "$@" >&2
}

##
# VLET_SYSCONFDIR 
# Set the following variable when the configuration files or NOT under $VLET_INSTALL/etc ! 
# This is automaticaly done when performing a binary installation (gnu/linux style).
# Typically this file is already located in the SYSCONFDIR ! 
# Specifying here has no effect, It should already (at an earlier stage) be set. 
#VLET_SYSCONFDIR=/etc/vlet

### 
# Runtime enviroment
# Local: cygwin 

case `uname` in 
 CYGWIN*) 
      cygwin=true; 
      arch=cygwin
      ;; 
 Linux*|linux*)
      linux==true; 
      arch=linux
      ;; 
 *) 
 	# Windows has it own startup exe file 
      ;; 
esac

###
# startup directory: 
# Global: BASE_DIR VLET_INSTALL

BINDIR=`dirname "$0"`
# resolve optional relative path !
BINDIR=`cd "$BINDIR" ; pwd` 
BASE_DIR=`dirname "$BINDIR"` 
	
if [ -n  "$VLET_INSTALL" ] ; then 
    BASE_DIR="$VLET_INSTALL"
    # keep BINDIR 
elif [ -n "$VLET_SYSCONFDIR" ] ; then 
    # $VLET_SYSCONFDIR/etc/vlerc.prop should hold VLET_INSTALL as 'vlet.install'
    #println "Reading: $VLET_SYSCONFDIR/vletrc.prop"
    VLET_INSTALL=`grep -v "#" "$VLET_SYSCONFDIR/vletrc.prop" | grep 'vlet.install=' | cut -d '=' -f 2` 
    # keep BINDIR as-is 
fi

# still empty ? 
if [ -z "$VLET_INSTALL" ] ; then 
    # find base installation dir. Assume script is started from $VLET_INSTALL/bin
    VLET_INSTALL="$BASE_DIR"
    # keep BINDIR
fi

export VLET_INSTALL 

##
# VBrowser jar
# 
# vbrowser.jar is a subclass of the bootstrap class which does now
# the most configuration it muse be in the same location as this script

VBROWSER_JAR="$BINDIR/vbrowser.jar" 
 
###
# CLASSPATH
# Global: CLASSPATH 

# CLASSPATH not needed anymore: browser.jar/bootstrap.jar now configures java environment. 
# CLASSPATH="$CLASSPATH:$VLET_INSTALL:$VLET_SYSCONFDIR/etc"


###
# Libraries
# Global: LD_LIBRARY_PATH
# to be moved (currently not needed) to bootstrap class. 
#LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$VLET_INSTALL/lib/linux:$VLET_INSTALL/lib/auxlib/linux"
#export LD_LIBRARY_PATH


###
# Convert CYGWIN paths: 
#


if [ $cygwin == "true" ] ; then 
   # convert unix style paths to windows compatible 
   println "--- Cygwin detected ---" 
   # cehck optional empty CLASSPATH
   if [ -n "$CLASSPATH" ] ; then 
       CLASSPATH=`cygpath -m -p $CLASSPATH` 
   fi
   VLET_INSTALL=`cygpath -m $VLET_INSTALL`
   VLET_SYSCONFDIR=`cygpath -m $VLET_SYSCONFDIR`
   # PATCH: to avoid the use of windows' find.exe make 
   # sure the Cygwin path is searched first.
   PATH="/usr/bin:$PATH"
   # windows does not have a LD_LIBRARY_PATH, it uses PATH instead:
   PATH="$PATH:$VLET_INSTALL/lib/win:$VLET_INSTALL/lib/auxlib/win"
   VBROWSER_JAR=`cygpath -w "$VBROWSER_JAR"`  
fi

###
# Check java version 
# Global: JAVA_HOME, JAVA 

if [ -n "$JAVA_HOME" ] ; then 
   # let JAVA_HOME override the default 'java' command 
   JAVA="$JAVA_HOME/bin/java"
   println "java=$JAVA_HOME/bin/java"
else
   # use default java command from path
   if which java ; then 
    	 println "java:using default java command from path." 
   else 
  	  println "*** Error: No Java Found ***"
  	  println " Java was not found on your path."
  	  println " Please set JAVA_HOME or put JAVA_HOME/bin on your PATH"
  	  println ""
  	  exit
    fi 
    JAVA=java
fi 

# heck java

export JAVA 

VERSION=`"$JAVA" -version 2>&1 | grep "version" |  sed "s/.*\([0-9].[0-9_]*\.[0-9_]*\).*/\1/"` 
MINOR=`echo $VERSION | cut -d '.' -f 2`

if [ "$MINOR" -lt 5 ] ; then 
   println "*** Wrong java version ***"
   println " You need java 1.5. Current version="$VERSION
   println " Current used java location="$JAVA 
   println " You can specify the java location by seting JAVA_HOME" 
   exit 1
fi  

###
#Exit: 
#When sourced, no return status must be given


